@@ -6,8 +6,13 @@ else:
     from . import utils
 
 def get_data(root):
+    download(root)
+    extract(root)
+    utils.print_finish(root)
+
+def download(root):
     import gdown
-    utils.print_start(root)
+    utils.print_start1(root)
     with utils.data_directory(root):
         downloads = [
             ('https://drive.google.com/uc?id=1nkh-g6a8JvWy-XsMaZqrN2AXoPlaXuFg', 'iPanda50-images.zip'),
@@ -17,8 +22,18 @@ def get_data(root):
 
         for url, archive in downloads:
             gdown.download(url, archive, quiet=False)
+
+def extract(root):
+    utils.print_start2(root)
+    with utils.data_directory(root):
+        downloads = [
+            ('https://drive.google.com/uc?id=1nkh-g6a8JvWy-XsMaZqrN2AXoPlaXuFg', 'iPanda50-images.zip'),
+            ('https://drive.google.com/uc?id=1gVREtFWkNec4xwqOyKkpuIQIyWU_Y_Ob', 'iPanda50-split.zip'),
+            ('https://drive.google.com/uc?id=1jdACN98uOxedZDT-6X3rpbooLAAUEbNY', 'iPanda50-eyes-labels.zip'),
+        ]
+
+        for url, archive in downloads:
             utils.extract_archive(archive, delete=True)
-    utils.print_finish(root)
 
 
 if __name__ == '__main__':
