@@ -7,16 +7,24 @@ else:
     from . import utils
 
 def get_data(root):
-    utils.print_start(root)
+    download(root)
+    extract(root)
+    utils.print_finish(root)
+
+def download(root):
+    utils.print_start1(root)
     with utils.data_directory(root):
         utils.kaggle_download(f"competitions download -c noaa-right-whale-recognition")
+
+def extract(root):
+    utils.print_start2(root)
+    with utils.data_directory(root):
         utils.extract_archive('noaa-right-whale-recognition.zip', delete=True)
         utils.extract_archive('imgs.zip', delete=True)
 
         # Move misplaced image
         shutil.move('w_7489.jpg', 'imgs')
         os.remove('w_7489.jpg.zip')
-    utils.print_finish(root)
 
 
 if __name__ == '__main__':
