@@ -7,8 +7,13 @@ else:
     from . import utils
 
 
-def get_data(root):    
-    utils.print_start(root)
+def get_data(root):
+    download(root)
+    extract(root)
+    utils.print_finish(root)
+
+def download(root):
+    utils.print_start1(root)
     with utils.data_directory(root):
         # TODO: does not work. it is specific for specific distros, isnt it?
         # TODO: Yes this is Ubuntu/linux specific.
@@ -19,14 +24,22 @@ def get_data(root):
         url = "https://lilablobssc.blob.core.windows.net/wni-giraffes/wni_giraffes_train_images.zip"
         archive = 'wni_giraffes_train_images.zip'
         os.system(f'azcopy cp {url} {archive}')
-        utils.extract_archive(archive, delete=True)
 
         # Metadata
         url = 'https://lilablobssc.blob.core.windows.net/wni-giraffes/wni_giraffes_train.zip'
         archive = 'wni_giraffes_train.zip'
         utils.download_url(url, archive)
+
+def extract(root):
+    utils.print_start2(root)
+    with utils.data_directory(root):
+        # Images
+        archive = 'wni_giraffes_train_images.zip'
+        utils.extract_archive(archive, delete=True)
+
+        # Metadata
+        archive = 'wni_giraffes_train.zip'
         utils.extract_archive(archive, delete=True)
-    utils.print_finish(root)
 
 
 if __name__ == '__main__':
